@@ -7,6 +7,8 @@ __email__ = "myron.walker@gmail.com"
 __status__ = "Development" # Prototype, Development or Production
 __license__ = "MIT"
 
+from typing import Optional
+
 class BaseCredential:
     """
         The :class:`BaseCredential` is the base container object for credentials passed in the landscape
@@ -16,10 +18,11 @@ class BaseCredential:
             "identifier": "player-ssh"
             "category": "(category)"
     """
-    def __init__(self, identifier: str = "", category: str = "", role: str = "priv"):
+    def __init__(self, *, identifier: str, category: str, role: Optional[str]="priv"):
         """
             :param identifier: The identifier that is used to reference this credential.  (required)
             :param category: The category of credential.
+            :param role: Identifies the role of the credential
         """
         if len(identifier) == 0:
             raise ValueError("The MuseCredential constructor requires a 'identifier' parameter be provided.")
